@@ -86,7 +86,7 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     KConfigGroup grp(KSharedConfig::openConfig(), "ConnectionsWidget");
     m_editor->connectionsWidget->header()->restoreState(grp.readEntry<QByteArray>("state", QByteArray()));
 
-    connect(m_editor->connectionsWidget, &QTreeView::pressed, this, &ConnectionEditor::slotItemClicked);
+    connect(m_editor->connectionsWidget->selectionModel(), &QItemSelectionModel::currentChanged, this, &ConnectionEditor::slotSelectionChanged);
     connect(m_editor->connectionsWidget, &QTreeView::doubleClicked, this, &ConnectionEditor::slotItemDoubleClicked);
     connect(m_editor->connectionsWidget, &QTreeView::customContextMenuRequested, this, &ConnectionEditor::slotContextMenuRequested);
     connect(m_menu->menu(), SIGNAL(triggered(QAction*)),
@@ -368,6 +368,22 @@ void ConnectionEditor::connectConnection()
     m_handler->activateConnection(connectionPath, devicePath, specificPath);
 }
 
+void ConnectionEditor::dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight, const QVector< int >& roles)
+{
+    Q_UNUSED(roles);
+    QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
+    if (currentIndex.isValid()) {
+        for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
+            QModelIndex index = m_editor->connectionsWidget->model()->index(i, 0);
+            if (index.isValid() && index == currentIndex) {
+                // Re-check enabled/disabled actions
+                slotSelectionChanged(currentIndex, currentIndex);
+                break;
+            }
+        }
+    }
+}
+
 void ConnectionEditor::disconnectConnection()
 {
     const QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
@@ -395,13 +411,12 @@ void ConnectionEditor::editConnection()
 void ConnectionEditor::initializeConnections()
 {
     EditorIdentityModel * model = new EditorIdentityModel(this);
-
     EditorProxyModel * filterModel = new EditorProxyModel(this);
     filterModel->setSourceModel(model);
+    connect(filterModel, &EditorProxyModel::dataChanged, this, &ConnectionEditor::dataChanged);
 
     m_editor->connectionsWidget->setModel(filterModel);
     m_editor->ktreewidgetsearchline->setProxy(filterModel);
-
     m_editor->connectionsWidget->header()->setSectionResizeMode(0, QHeaderView::Stretch);
 }
 
@@ -450,7 +465,7 @@ void ConnectionEditor::slotContextMenuRequested(const QPoint&)
     menu->exec(QCursor::pos());
 }
 
-void ConnectionEditor::slotItemClicked(const QModelIndex &index)
+void ConnectionEditor::slotSelectionChanged(const QModelIndex &index, const QModelIndex &previous)
 {
     if (!index.isValid()) {
         return;
@@ -467,10 +482,11 @@ void ConnectionEditor::slotItemClicked(const QModelIndex &index)
         actionCollection()->action("export_vpn")->setEnabled(false);
     } else {                       //connection
         const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+        const bool isActivating = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activating;
         const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
 
-        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive);
-        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && isActive);
+        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive && !isActivating);
+        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && (isActive || isActivating));
         actionCollection()->action("edit_connection")->setEnabled(true);
         actionCollection()->action("delete_connection")->setEnabled(true);
         const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
