@@ -149,14 +149,14 @@ void IPv6Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     // dns
     QStringList tmp;
-    foreach (const QHostAddress & addr, ipv6Setting->dns()) {
+    Q_FOREACH(const QHostAddress & addr, ipv6Setting->dns()) {
         tmp.append(addr.toString());
     }
     m_ui->dns->setText(tmp.join(","));
     m_ui->dnsSearch->setText(ipv6Setting->dnsSearch().join(","));
 
     // addresses
-    foreach (const NetworkManager::IpAddress &address, ipv6Setting->addresses()) {
+    Q_FOREACH(const NetworkManager::IpAddress &address, ipv6Setting->addresses()) {
         QList<QStandardItem *> item;
 
         item << new QStandardItem(address.ip().toString())
@@ -212,7 +212,7 @@ QVariantMap IPv6Widget::setting(bool agentOwned) const
     if (m_ui->dns->isEnabled() && !m_ui->dns->text().isEmpty()) {
         QStringList tmp = m_ui->dns->text().split(',');
         QList<QHostAddress> tmpAddrList;
-        foreach (const QString & str, tmp) {
+        Q_FOREACH(const QString & str, tmp) {
             QHostAddress addr(str);
             if (!addr.isNull())
                 tmpAddrList.append(addr);
@@ -471,7 +471,7 @@ bool IPv6Widget::isValid() const
 
     if (!m_ui->dns->text().isEmpty() && (m_ui->method->currentIndex() == Automatic || m_ui->method->currentIndex() == Manual || m_ui->method->currentIndex() == AutomaticOnlyIP)) {
         const QStringList tmp = m_ui->dns->text().split(',');
-        foreach (const QString & str, tmp) {
+        Q_FOREACH(const QString & str, tmp) {
             QHostAddress addr(str);
             if (addr.isNull()) {
                 return false;
