@@ -429,7 +429,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr& connecti
         if (item->type() == NetworkManager::ConnectionSettings::Wireless) {
             item->setMode(wirelessSetting->mode());
             item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
-            item->setSsid(wirelessSetting->ssid());
+            item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
         } else if (item->type() == NetworkManager::ConnectionSettings::Wimax) {
             item->setNsp(wimaxSetting->networkName());
         }
@@ -807,7 +807,7 @@ void NetworkModel::connectionUpdated()
                 wirelessSetting = settings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
                 item->setMode(wirelessSetting->mode());
                 item->setSecurityType(NetworkManager::securityTypeFromConnectionSetting(settings));
-                item->setSsid(wirelessSetting->ssid());
+                item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
                 // TODO check whether BSSID has changed and update the wireless info
             } else if (item->type() == NetworkManager::ConnectionSettings::Wimax) {
                 NetworkManager::WimaxSetting::Ptr wimaxSetting;
